﻿using System;
using System.Collections.Generic;
using System.Diagnostics;

namespace SyumasGen
{
    /// <summary>
    /// データリスト管理クラス
    /// </summary>
    class DataList
    {
        /// <summary>ランキングデータ</summary>
        public List<RankingData> RankingList = new List<RankingData>();

        /// <summary>ピックアップデータ</summary>
        public List<PickupData> PickupList = new List<PickupData>();

        /// <summary>社長カットイン順位データ</summary>
        public List<CutInData> TakagiList = new List<CutInData>();

        /// <summary>除外リストデータ</summary>
        public List<JogaiData> JogaiList = new List<JogaiData>();

        /// <summary>集計概要データ</summary>
        public List<SummaryData> SummaryList = new List<SummaryData>();

        /// <summary>出演回数データ</summary>
        public List<StageData> StageList = new List<StageData>();

        /// <summary>登録数及び再生数の順位データ</summary>
        public List<PlayRankData> PlayRankList = new List<PlayRankData>();

        /// <summary>圏外リストデータ</summary>
        public List<OutRangeData> OutRangeList = new List<OutRangeData>();

        /// <summary>
        /// Excelファイルからデータを読み込む
        /// </summary>
        /// <returns></returns>
        public void ReadFile(string path, Settings option)
        {
            ExcelCom excel = null;

            try
            {
                excel = new ExcelCom();
                excel.OpenFile(path);

                // ---------- ランキング情報取得
                excel.AvtivateSheet("ranking");
                int row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 19);
                    RankingData data = new RankingData(s);
                    RankingList.Add(data);
                    row++;
                }

                // --------- ピックアップ情報取得
                excel.AvtivateSheet("pickup");
                row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 10);
                    PickupData data = new PickupData(s);
                    PickupList.Add(data);
                    row++;
                }

                // --------- 社長カットイン順位情報取得
                excel.AvtivateSheet("cutin");
                row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 6);
                    CutInData data = new CutInData(s);
                    TakagiList.Add(data);
                    row++;
                }

                // ---------- 除外リスト情報取得
                excel.AvtivateSheet("jogai");
                row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 8);
                    JogaiData data = new JogaiData(s);
                    JogaiList.Add(data);
                    row++;
                }

                // ---------- 集計概要リスト情報取得
                excel.AvtivateSheet("summary");
                row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 4);
                    SummaryData data = new SummaryData(s);
                    SummaryList.Add(data);
                    row++;
                }

                // ---------- 出演回数情報取得
                excel.AvtivateSheet("stage");
                row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 10);
                    StageData data = new StageData(s);
                    StageList.Add(data);
                    row++;
                }

                // ---------- 登録数及び再生数の順位取得
                excel.AvtivateSheet("play_rank");
                row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 6);
                    PlayRankData data = new PlayRankData(s);
                    PlayRankList.Add(data);
                    row++;
                }

                // ---------- 
                excel.AvtivateSheet("out_of_range_list");
                row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    string[] s = GetCellData(excel, row, 1, 5);
                    OutRangeData data = new OutRangeData(s);
                    OutRangeList.Add(data);
                    row++;
                }
            }
            catch (Exception ex)
            {
                Debug.WriteLine(ex.ToString());
                throw ex;
            }
            finally
            {
                if (excel != null)
                {
                    excel.Quit();
                    excel.Dispose();
                }
            }
        }

        /// <summary>
        /// Excelのセルからデータを取得
        /// </summary>
        /// <param name="excel"></param>
        /// <param name="row"></param>
        /// <param name="startCol"></param>
        /// <param name="endCol"></param>
        /// <returns></returns>
        private string[] GetCellData(ExcelCom excel, int row, int startCol, int endCol)
        {
            string[] s = new string[endCol - startCol + 1];
            int i = 0;

            for (int col = startCol; col <= endCol; col++)
            {
                s[i++] = excel.GetValue(row, col);
            }

            return s;
        }
    }
}
