﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Windows.Forms;
using System.Collections.Generic;

namespace SyumasGen
{
    /// <summary>
    /// 登録数及び再生数の順位リスト画像
    /// </summary>
    class ImagePlayRank
    {
        /// <summary>
        /// 登録数及び再生数の順位リストの画像を描画します。
        /// </summary>
        /// <param name="g"></param>
        /// <param name="data"></param>
        /// <param name="option"></param>
        internal static void Draw(Graphics g, DataList data, Settings option)
        {
            // 描画エリアのクリア（背景色は黄色）
            g.Clear(Color.FromArgb(255, ImageGen._BackColorYellow));

            // フォントの設定
            TextInfoData textInfo = option.TextInfoList[TextInfoKind.PlayRankText];
            Font titleFont = new Font(textInfo.FontName, 18, FontStyle.Bold);
            Font textFont = new Font(textInfo.FontName, textInfo.FontSize, FontStyle.Bold);

            // タイトル、項目描画
            ImageGen.DrawText(g, "┗登録数及び再生数の順位┣", titleFont, Brushes.Black, 0, 15, Align.ScreenCenter);

            int y = 50;
            ImageGen.DrawText(g, "タイトル", textFont, Brushes.Black, 20, y, Align.Left);
            ImageGen.DrawText(g, "順位", textFont, Brushes.Black, 315, y, Align.Center);
            ImageGen.DrawText(g, "登録順位", textFont, Brushes.Black, 360, y, Align.Center);
            ImageGen.DrawText(g, "再生順位", textFont, Brushes.Black, 450, y, Align.Center);

            // 出演回数本体描画
            List<PlayRankData> list = data.PlayRankList;
            int height = 20;
            y = 70;

            for (int i = 0; i < list.Count; i++)
            {
                Color c = Color.Black;
                int rank = 0;

                // タイトル
                ImageGen.DrawText(g, list[i].Title, textFont, Brushes.Black, 20, y, Align.Left);

                // 順位
                rank = list[i].Rank;
                c = rank == 1 ? Color.Red : rank == 2 ? Color.Blue : rank == 3 ? Color.Green : Color.Black;
                ImageGen.DrawText(g, list[i].Rank.ToString(), textFont, new SolidBrush(c), 320, y, Align.Right);

                // 登録順位（登録数）
                rank = list[i].MylistRank;
                c = rank == 1 ? Color.Red : rank == 2 ? Color.Blue : rank == 3 ? Color.Green : Color.Black;
                ImageGen.DrawText(g, list[i].MylistRank.ToString(), textFont, new SolidBrush(c), 345, y, Align.Right);

                if (list[i].Mylist > 0)
                {
                    string s = list[i].Mylist.ToString("(#,##0)");
                    ImageGen.DrawText(g, s, textFont, new SolidBrush(c), 345, y, Align.Left);
                }

                // 再生順位（再生数）
                rank = list[i].PlayRank;
                c = rank == 1 ? Color.Red : rank == 2 ? Color.Blue : rank == 3 ? Color.Green : Color.Black;
                ImageGen.DrawText(g, list[i].PlayRank.ToString(), textFont, new SolidBrush(c), 430, y, Align.Right);

                if (list[i].Play > 0)
                {
                    string s = list[i].Play.ToString("(#,##0)");
                    ImageGen.DrawText(g, s, textFont, new SolidBrush(c), 430, y, Align.Left);
                }

                y += height;
            }

            titleFont.Dispose();
            textFont.Dispose();
        }
    }
}
