﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Windows.Forms;
using System.Collections.Generic;

namespace SyumasGen
{
    /// <summary>
    /// 今週の集計概要及び出演回数リスト画像
    /// </summary>
    class ImageSummary
    {
        /// <summary>
        /// 今週の集計概要及び出演回数リスト画像を描画します。
        /// </summary>
        /// <param name="g"></param>
        /// <param name="data"></param>
        /// <param name="option"></param>
        internal static void Draw(Graphics g, DataList data, Settings option)
        {
            // 描画エリアのクリア（背景色は黄色）
            g.Clear(Color.FromArgb(255, ImageGen._BackColorYellow));

            // フォントの設定
            TextInfoData textInfo = option.TextInfoList[TextInfoKind.SummaryText];
            Font textFont = new Font(textInfo.FontName, textInfo.FontSize, FontStyle.Bold);

            // 集計概要タイトル描画
            ImageGen.DrawText(g,"┗今週の集計概要┣", textFont, Brushes.Black, 0, 10, Align.ScreenCenter);

            // 集計概要本体描画
            List<SummaryData> summary = data.SummaryList;
            int baseY = 30;
            int height = 17;

            int y = baseY;

            for (int i = 0; i < summary.Count; i++)
            {
                // 項目名
                ImageGen.DrawText(g,summary[i].Name, textFont, Brushes.Black, 155, y, Align.Right);

                // 今週分
                ImageGen.DrawText(g,summary[i].ThisWeek.ToString("#,##0"), textFont, Brushes.Black, 235, y, Align.Right);

                // 先週比
                ImageGen.DrawText(g,"(先週比:", textFont, Brushes.Black, 245, y, Align.Left);

                Color c = summary[i].LastWeekDiff > 0 ? Color.Red : summary[i].LastWeekDiff < 0 ? Color.Blue : Color.Black;

                string lastWeekDiff = summary[i].LastWeekDiff.ToString("▲#,##0;▼#,##0;±0");
                ImageGen.DrawText(g,lastWeekDiff, textFont, new SolidBrush(c), 400, y, Align.Right);

                // 「作品数」の場合、新作数を描画、他は閉じ括弧のみ
                if (i == 0)
                {
                    string newVideos = "、新作:" + summary[i].NewVideos.ToString("#,##0") + ")";
                    ImageGen.DrawText(g,newVideos, textFont, Brushes.Black, 400, y, Align.Left);
                }
                else
                {
                    ImageGen.DrawText(g,")", textFont, Brushes.Black, 405, y, Align.Left);
                }

                y += height;
            }

            // 出演回数タイトル、項目描画
            ImageGen.DrawText(g,"┗アイドル別出演回数┣", textFont, Brushes.Black, 0, 90, Align.ScreenCenter);

            y = 110;
            ImageGen.DrawText(g,"名前", textFont, Brushes.Black, 60, y, Align.Left);
            ImageGen.DrawText(g,"ソロ", textFont, Brushes.Black, 160, y, Align.Center);
            ImageGen.DrawText(g,"ペア", textFont, Brushes.Black, 220, y, Align.Center);
            ImageGen.DrawText(g,"他(ｾﾝﾀｰ)", textFont, Brushes.Black, 290, y, Align.Center);
            ImageGen.DrawText(g,"合計", textFont, Brushes.Black, 363, y, Align.Center);
            ImageGen.DrawText(g,"名前", textFont, Brushes.Black, 450, y, Align.Right);

            // 出演回数本体描画
            List<StageData> stage = data.StageList;
            baseY = 130;
            height = 17;

            y = baseY;

            for (int i = 0; i < stage.Count; i++)
            {
                Color c = Color.Black;

                // 名前
                ImageGen.DrawText(g,stage[i].Name, textFont, Brushes.Black, 60, y, Align.Left);

                // ソロ
                c = stage[i].SoloColor == "" ? Color.Black : Color.FromName(stage[i].SoloColor);
                ImageGen.DrawText(g,stage[i].Solo.ToString(), textFont, new SolidBrush(c), 165, y, Align.Right);

                // ペア
                c = stage[i].PairColor == "" ? Color.Black : Color.FromName(stage[i].PairColor);
                ImageGen.DrawText(g,stage[i].Pair.ToString(), textFont, new SolidBrush(c), 225, y, Align.Right);

                // 他
                c = stage[i].OtherColor == "" ? Color.Black : Color.FromName(stage[i].OtherColor);
                ImageGen.DrawText(g,stage[i].Other.ToString(), textFont, new SolidBrush(c), 285, y, Align.Right);

                // センター
                if (stage[i].Center > 0)
                {
                    ImageGen.DrawText(g,"(" + stage[i].Center + ")", textFont, new SolidBrush(c), 290, y, Align.Left);
                }

                // 合計
                c = stage[i].TotalColor == "" ? Color.Black : Color.FromName(stage[i].TotalColor);
                ImageGen.DrawText(g,stage[i].Total.ToString(), textFont, new SolidBrush(c), 370, y, Align.Right);

                // 名前
                ImageGen.DrawText(g,stage[i].Name, textFont, Brushes.Black, 450, y, Align.Right);

                y += height;
            }

            textFont.Dispose();
        }
    }
}
